@@ -1,6 +1,6 @@
-"""Datafeed for current price of ETH in JPY used by LegacyQueryReporter."""
+"""Datafeed for current price of ETH in JPY."""
 from telliot_feeds.datafeed import DataFeed
-from telliot_feeds.queries import SpotPrice
+from telliot_feeds.queries.price.spot_price import SpotPrice
 from telliot_feeds.sources.price.spot.bitfinex import BitfinexSpotPriceSource
 from telliot_feeds.sources.price.spot.bitflyer import BitflyerSpotPriceSource
 from telliot_feeds.sources.price.spot.coingecko import CoinGeckoSpotPriceSource
