@@ -2,7 +2,7 @@
 EUR/USD SpotPrice DataFeed
 """
 from telliot_feeds.datafeed import DataFeed
-from telliot_feeds.queries import SpotPrice
+from telliot_feeds.queries.price.spot_price import SpotPrice
 from telliot_feeds.sources.price.currency.coinbase import CoinbaseCurrencyPriceSource
 from telliot_feeds.sources.price.currency.openexchangerate import OpenExchangeRateCurrencyPriceSource
 from telliot_feeds.sources.price_aggregator import PriceAggregator
