@@ -1,5 +1,5 @@
 from telliot_feeds.datafeed import DataFeed
-from telliot_feeds.queries import SpotPrice
+from telliot_feeds.queries.price.spot_price import SpotPrice
 from telliot_feeds.sources.price.spot.binance import BinanceSpotPriceSource
 from telliot_feeds.sources.price.spot.bittrex import BittrexSpotPriceSource
 from telliot_feeds.sources.price.spot.coinbase import CoinbaseSpotPriceSource
