@@ -5,6 +5,7 @@ from telliot_feeds.queries.daily_volatility import DailyVolatility
 from telliot_feeds.queries.diva_protocol import DIVAProtocol
 from telliot_feeds.queries.evm_call import EVMCall
 from telliot_feeds.queries.gas_price_oracle import GasPriceOracle
+from telliot_feeds.queries.mimicry import MimicryCollectionStat
 from telliot_feeds.queries.numeric_api_response_query import NumericApiResponse
 from telliot_feeds.queries.price.spot_price import SpotPrice
 from telliot_feeds.queries.price.twap import TWAP
@@ -287,3 +288,33 @@ query_catalog.add_entry(
     title="YFI/USD spot price",
     q=SpotPrice(asset="yfi", currency="usd"),
 )
+
+query_catalog.add_entry(
+    tag="mimicry-crypto-coven-tami",
+    title="Crypto Coven TAMI calculation for Mimicry",
+    q=MimicryCollectionStat(collectionAddress="0x5180db8F5c931aaE63c74266b211F580155ecac8", chainId=1, metric=0),
+)
+
+query_catalog.add_entry(
+    tag="steth-btc-spot",
+    title="STETH/BTC spot price",
+    q=SpotPrice(asset="steth", currency="btc"),
+)
+
+query_catalog.add_entry(
+    tag="steth-usd-spot",
+    title="STETH/USD spot price",
+    q=SpotPrice(asset="steth", currency="usd"),
+)
+
+query_catalog.add_entry(
+    tag="reth-btc-spot",
+    title="RETH/BTC spot price",
+    q=SpotPrice(asset="reth", currency="btc"),
+)
+
+query_catalog.add_entry(
+    tag="reth-usd-spot",
+    title="RETH/USD spot price",
+    q=SpotPrice(asset="reth", currency="usd"),
+)
