@@ -29,6 +29,10 @@ from telliot_feeds.utils.log import get_logger
 logger = get_logger(__name__)
 
 
+# chains where autopay contract is deployed
+AUTOPAY_CHAINS = (137, 80001, 69, 1666600000, 1666700000, 421611, 42161, 10200, 100, 10, 420, 421613, 3141)
+
+
 @dataclass
 class Tag:
     query_tag: str
@@ -127,9 +131,9 @@ class AutopayCalls:
 
         # separate items from current feeds
         # multicall for multiple different functions returns different types of data at once
-        # ie the response is {"tag": (feedids, ), ('trb-usd-legacy', 'current_time'): 0,
-        # ('trb-usd-legacy', 'three_mos_ago'): 0,eth-jpy-legacy: (),'eth-jpy-legacy', 'current_time'): 0,
-        # ('eth-jpy-legacy', 'three_mos_ago'): 0}
+        # ie the response is {"tag": (feedids, ), ('trb-usd-spot', 'current_time'): 0,
+        # ('trb-usd-spot', 'three_mos_ago'): 0,eth-jpy-spot: (),'eth-jpy-spot', 'current_time'): 0,
+        # ('eth-jpy-spot', 'three_mos_ago'): 0}
         # here we filter out the tag key if it is string and its value is of length > 0
 
         tags_with_feed_ids = {
@@ -366,7 +370,7 @@ async def autopay_suggested_report(
     Return: query id, tip amount
     """
     chain = autopay.node.chain_id
-    if chain in (137, 80001, 69, 1666600000, 1666700000, 421611, 42161):
+    if chain in AUTOPAY_CHAINS:
 
         # get query_ids with one time tips
         singletip_dict = await get_one_time_tips(autopay)
@@ -395,6 +399,7 @@ async def autopay_suggested_report(
         else:
             return None, None
     else:
+        logger.warning(f"Chain {chain} does not have Autopay contract support")
         return None, None
 
 
