@@ -49,6 +49,8 @@ coingecko_coin_id = {
     "uni": "uniswap",
     "usdt": "tether",
     "yfi": "yearn-finance",
+    "steth": "staked-ether",
+    "reth": "rocket-pool-eth",
 }
 
 
