@@ -7,13 +7,11 @@ from datetime import datetime
 from unittest import mock
 
 import pytest
-from telliot_core.gas.legacy_gas import ethgasstation
 from telliot_core.utils.response import ResponseStatus
 from web3.datastructures import AttributeDict
 
 from telliot_feeds.datafeed import DataFeed
-from telliot_feeds.feeds.eth_usd_feed import eth_usd_median_feed
-from telliot_feeds.reporters import interval
+from telliot_feeds.feeds.matic_usd_feed import matic_usd_median_feed
 from telliot_feeds.sources.etherscan_gas import EtherscanGasPrice
 from tests.utils.utils import gas_price
 from tests.utils.utils import passing_bool_w_status
@@ -32,9 +30,10 @@ async def test_fetch_datafeed(tellor_flex_reporter):
     assert isinstance(feed, DataFeed)
 
 
+@pytest.mark.skip(reason="EIP-1559 not supported by ganache")
 @pytest.mark.asyncio
-async def test_get_fee_info(tellor_flex_reporter):
-    info, time = await tellor_flex_reporter.get_fee_info()
+def test_get_fee_info(tellor_flex_reporter):
+    info, time = tellor_flex_reporter.get_fee_info()
 
     assert isinstance(time, datetime)
     assert isinstance(info, EtherscanGasPrice)
@@ -46,7 +45,7 @@ async def test_get_fee_info(tellor_flex_reporter):
 @pytest.mark.asyncio
 async def test_get_num_reports_by_id(tellor_flex_reporter):
     r = tellor_flex_reporter
-    num, status = await r.get_num_reports_by_id(eth_usd_median_feed.query.query_id)
+    num, status = await r.get_num_reports_by_id(matic_usd_median_feed.query.query_id)
 
     assert isinstance(status, ResponseStatus)
 
@@ -65,24 +64,11 @@ async def test_ensure_staked(tellor_flex_reporter):
     assert status.ok
 
 
-@pytest.mark.asyncio
-async def test_check_reporter_lock(tellor_flex_reporter):
-    """Test checking if in reporter lock."""
-    r = tellor_flex_reporter
-    r.last_submission_timestamp = 0
-
-    status = await r.check_reporter_lock()
-
-    assert isinstance(status, ResponseStatus)
-    if not status.ok:
-        assert status.error == "Current address is in reporter lock."
-        assert r.last_submission_timestamp != 0
-
-
 @pytest.mark.asyncio
 async def test_ensure_profitable(tellor_flex_reporter):
     """Test profitability check."""
     r = tellor_flex_reporter
+    r.gas_info = {"type": 0, "gas_price": 1e9, "gas_limit": 300000}
 
     assert r.expected_profit == "YOLO"
 
@@ -97,42 +83,16 @@ async def test_ensure_profitable(tellor_flex_reporter):
     assert status.error == "Estimated profitability below threshold."
 
 
-@pytest.mark.asyncio
-async def test_fetch_gas_price(tellor_flex_reporter):
-    """Test retrieving custom gas price from eth gas station."""
-    r = tellor_flex_reporter
-
-    assert r.gas_price_speed == "safeLow"
-
-    r.gas_price_speed = "average"
-
-    assert r.gas_price_speed != "safeLow"
-
-    gas_price = await r.fetch_gas_price()
-
-    assert isinstance(gas_price, int)
-    assert gas_price > 0
-
-
 @pytest.mark.asyncio
 async def test_ethgasstation_error(tellor_flex_reporter):
-    async def no_gas_price(speed):
-        return None
+    with mock.patch("telliot_feeds.reporters.interval.IntervalReporter.fetch_gas_price") as func:
+        func.return_value = None
+        r = tellor_flex_reporter
+        r.stake = 1000000 * 10**18
 
-    r = tellor_flex_reporter
-    interval.ethgasstation = no_gas_price
-
-    staked, status = await r.ensure_staked()
-    assert not staked
-    assert not status.ok
-
-    status = await r.ensure_profitable(eth_usd_median_feed)
-    assert not status.ok
-
-    tx_receipt, status = await r.report_once()
-    assert tx_receipt is None
-    assert not status.ok
-    interval.ethgasstation = ethgasstation
+        staked, status = await r.ensure_staked()
+        assert not staked
+        assert not status.ok
 
 
 @pytest.mark.asyncio
@@ -172,6 +132,7 @@ async def test_interval_reporter_submit_once(tellor_flex_reporter):
 async def test_no_updated_value(tellor_flex_reporter, bad_datasource):
     """Test handling for no updated value returned from datasource."""
     r = tellor_flex_reporter
+    r.datafeed = matic_usd_median_feed
 
     # Clear latest datapoint
     r.datafeed.source._history.clear()
@@ -192,6 +153,7 @@ async def test_no_updated_value(tellor_flex_reporter, bad_datasource):
     assert status.error == "Unable to retrieve updated datafeed value."
 
 
+@pytest.mark.skip("ensure_profitable is overritten in TelloFlexReporter")
 @pytest.mark.asyncio
 async def test_no_token_prices_for_profit_calc(tellor_flex_reporter, bad_datasource, guaranteed_price_source):
     """Test handling for no token prices for profit calculation."""
@@ -220,6 +182,7 @@ async def test_no_token_prices_for_profit_calc(tellor_flex_reporter, bad_datasou
     assert status.error == "Unable to fetch ETH/USD price for profit calculation"
 
 
+@pytest.mark.skip("ensure_staked is overritten in TelloFlexReporter")
 @pytest.mark.asyncio
 async def test_handle_contract_master_read_timeout(tellor_flex_reporter):
     """Test handling for contract master read timeout."""
@@ -238,20 +201,17 @@ async def test_handle_contract_master_read_timeout(tellor_flex_reporter):
 
 
 @pytest.mark.asyncio
-async def test_ensure_reporter_lock_check_after_submitval_attempt(
-    monkeypatch, tellor_flex_reporter, guaranteed_price_source
-):
+async def test_ensure_reporter_lock_check_after_submitval_attempt(tellor_flex_reporter, guaranteed_price_source):
     r = tellor_flex_reporter
     r.last_submission_timestamp = 1234
     r.fetch_gas_price = gas_price
     r.ensure_staked = passing_bool_w_status
     r.ensure_profitable = passing_status
-
-    assert r.datafeed
+    r.check_reporter_lock = passing_status
+    r.datafeed = matic_usd_median_feed
+    r.gas_limit = 350000
 
     # Simulate fetching latest value
-    r.eth_usd_median_feed.source.sources = [guaranteed_price_source]
-    r.trb_usd_median_feed.source.sources = [guaranteed_price_source]
     r.datafeed.source.sources = [guaranteed_price_source]
 
     async def num_reports(*args, **kwargs):
