@@ -1,7 +1,6 @@
 import pytest
 from brownie import accounts
 from brownie import Autopay
-from brownie import TellorFlex360
 from telliot_core.apps.core import TelliotCore
 from telliot_core.utils.timestamp import TimeStamp
 
@@ -9,39 +8,20 @@ from telliot_feeds.reporters.tips import CATALOG_QUERY_DATA
 from telliot_feeds.reporters.tips import CATALOG_QUERY_IDS
 
 
-trb_id = "0x5c13cd9c97dbb98f2429c101a2a8150e6c7a0ddaff6124ee176a3a411067ded0"
 txn_kwargs = {"gas_limit": 3500000, "legacy_gas_price": 1}
-account_fake = accounts.add("023861e2ceee1ea600e43cbd203e9e01ea2ed059ee3326155453a1ed3b1113a9")
 
 
 @pytest.fixture(scope="function")
-def tellorflex_360_contract(mock_token_contract):
-    return account_fake.deploy(
-        TellorFlex360,
-        mock_token_contract.address,
-        1,
-        1,
-        1,
-        trb_id,
-    )
-
-
-@pytest.fixture(scope="function")
-def autopay_contract(tellorflex_360_contract, mock_token_contract, query_data_storage_contract):
-    """mock payments(Autopay) contract for tipping and claiming tips"""
-    return accounts[0].deploy(
+async def autopay_contract_setup(
+    mumbai_test_cfg, tellorflex_360_contract, mock_token_contract, query_data_storage_contract
+):
+    autopay_contract = accounts[0].deploy(
         Autopay,
         tellorflex_360_contract.address,
         mock_token_contract.address,
         query_data_storage_contract.address,
         20,
     )
-
-
-@pytest.fixture(scope="function")
-async def autopay_contract_setup(
-    mumbai_test_cfg, tellorflex_360_contract, autopay_contract, mock_token_contract, multicall_contract
-):
     async with TelliotCore(config=mumbai_test_cfg) as core:
 
         # get PubKey and PrivKey from config files
@@ -118,11 +98,7 @@ async def setup_one_time_tips(autopay_contract_setup):
     """Tip all query ids in telliot"""
     flex = await autopay_contract_setup
     count = 1  # tip must be greater than zero
-    queries = [
-        item
-        for item in zip(CATALOG_QUERY_IDS, CATALOG_QUERY_DATA)
-        if CATALOG_QUERY_IDS[item[0]] != "tellor-rng-example"
-    ]
+    queries = [item for item in zip(CATALOG_QUERY_IDS, CATALOG_QUERY_DATA)]
     for query_id, query_data in queries:
 
         _, status = await flex.autopay.write(
