@@ -3,13 +3,13 @@ from brownie import chain
 from eth_utils import to_bytes
 from telliot_core.apps.core import TelliotCore
 
-from telliot_feeds.feeds.trb_usd_feed import trb_usd_median_feed
+from telliot_feeds.feeds.matic_usd_feed import matic_usd_median_feed
 from telliot_feeds.reporters.tellor_360 import Tellor360Reporter
 from telliot_feeds.reporters.tips.tip_amount import fetch_feed_tip
 
 
-query_data = trb_usd_median_feed.query.query_data
-query_id = trb_usd_median_feed.query.query_id
+query_data = matic_usd_median_feed.query.query_data
+query_id = matic_usd_median_feed.query.query_id
 reward = 1 * 10**18
 interval = 100
 window = 99
@@ -60,7 +60,7 @@ async def test_priceThreshold_gt_zero(autopay_contract_setup):
         **setup_datafeed_kwargs_big_window,
         _priceThreshold=price_threshold,
     )
-    get_price = await trb_usd_median_feed.source.fetch_new_datapoint()
+    get_price = await matic_usd_median_feed.source.fetch_new_datapoint()
     price = get_price[0]
     tip_amount = await fetch_feed_tip(autopay=r.autopay, query_id=query_id)
     assert tip_amount == reward
@@ -138,7 +138,7 @@ async def test_meet_priceThreshold(autopay_contract_setup):
     )
     tip_amount = await fetch_feed_tip(autopay=r.autopay, query_id=query_id)
     assert tip_amount == reward
-    get_price = await trb_usd_median_feed.source.fetch_new_datapoint()
+    get_price = await matic_usd_median_feed.source.fetch_new_datapoint()
     # report a price that is 1 less than the current price so that threshold is met
     price = get_price[0] - 1
     # report a price that is falls within the interval
