@@ -7,9 +7,9 @@ from web3 import Web3
 
 from telliot_feeds.datafeed import DataFeed
 from telliot_feeds.feeds import CATALOG_FEEDS
-from telliot_feeds.feeds.dai_usd_feed import dai_usd_median_feed
 from telliot_feeds.feeds.eth_usd_feed import eth_usd_median_feed
 from telliot_feeds.feeds.matic_usd_feed import matic_usd_median_feed
+from telliot_feeds.feeds.xdai_usd_feed import xdai_usd_median_feed
 from telliot_feeds.queries.query import OracleQuery
 from telliot_feeds.queries.query_catalog import query_catalog
 from telliot_feeds.utils.log import get_logger
@@ -90,7 +90,7 @@ def test_get_native_token_feed():
     assert f == matic_usd_median_feed
 
     f = get_native_token_feed(10200)
-    assert f == dai_usd_median_feed
+    assert f == xdai_usd_median_feed
 
     with pytest.raises(ValueError):
         _ = get_native_token_feed(0)
